@@ -1,19 +1,20 @@
 import functools
+from typing import Callable
 
 from ..config import is_dry
 
 
-def dryable(dry_func):
+def dryable(dry_func: Callable) -> Callable:
     """Function decorator to set a function as dryable.
 
     When this decorator is applied, the provided `dry_func` will be called
     instead of the actual function when the current run is a dry run.
 
-    :param dry_func: function to call when it is a dry run
-    :type dry_func: function
+    Args:
+        dry_func: Function to call when it is a dry run
 
-    :return: wrapped function
-    :rtype: function
+    Returns:
+        Wrapped function
     """
 
     def wrapper(func):
@@ -35,3 +36,13 @@ def dummy_function(*args, **kwargs):
     Used for making functions dryable.
     """
     return
+
+
+def undryable_function(*args, **kwargs):
+    """A dummy function that raises an exception. For use when a particular
+    function is not dryable.
+
+    Raises:
+        Exception: Always
+    """
+    raise Exception('This function is not dryable.')
