@@ -1,6 +1,7 @@
 import functools
 import os
 import re
+from typing import Callable
 
 import scipy.io
 
@@ -11,49 +12,49 @@ from .utils import run_executable
 BUSTOOLS_INSPECT_PARSER = re.compile(r'^.*?(?P<count>[0-9]+)')
 
 
-class FileVerificationFailed(Exception):
+class ValidateError(Exception):
     pass
 
 
-def validate_bus(path):
+def validate_bus(path: str):
     """Verify if the provided BUS file is valid.
 
     A BUS file is considered valid when `bustools inspect` can read
     the file + it has > 0 BUS records.
 
-    :param path: path to BUS file
-    :type path: str
+    Args:
+        path: Path to BUS file
 
-    :raises FileVerificationFailed: if the file failed verification
-    :raises subprocess.CalledProcessError: if the bustools command failed
+    Raises:
+        ValidateError: If the file failed verification
+        subprocess.CalledProcessError: If the bustools command failed
     """
     command = [get_bustools_binary_path(), 'inspect', path]
-    p = run_executable(command, quiet=True)
-    match = BUSTOOLS_INSPECT_PARSER.match(p.stdout.read())
+    p, stdout, stderr = run_executable(command, quiet=True)
+    match = BUSTOOLS_INSPECT_PARSER.match(stdout)
     if not match:
-        raise FileVerificationFailed(
-            ('bustools inspect output could not be parsed for {}'.format(path))
+        raise ValidateError(
+            f'bustools inspect output could not be parsed for {path}'
         )
     if int(match.groupdict().get('count', 0)) == 0:
-        raise FileVerificationFailed('{} has no BUS records'.format(path))
+        raise ValidateError(f'{path} has no BUS records')
 
 
-def validate_mtx(path):
+def validate_mtx(path: str):
     """Verify if the provided Matrix Market (.mtx) file is valid.
 
     A BUS file is considered valid when the file can be read with `scipy.io.mmread`.
 
-    :param path: path to mtx file
-    :type path: str
+    Args:
+        path: Path to mtx file
 
-    :raises FileVerificationFailed: if the file failed verification
+    Raises:
+        ValidateError: If the file failed verification
     """
     try:
         scipy.io.mmread(path)
     except ValueError:
-        raise FileVerificationFailed(
-            '{} is not a valid matrix market file'.format(path)
-        )
+        raise ValidateError(f'{path} is not a valid matrix market file')
 
 
 VALIDATORS = {
@@ -62,40 +63,45 @@ VALIDATORS = {
 }
 
 
-def validate(path):
+def validate(path: str):
     """Validate a file.
 
     This function is a wrapper around all validation functions.
     Given a path, it chooses the correct validation function.
     This function assumes the file exists.
 
-    :param path: path to file
-    :type path: str
+    Args:
+        path: Path to file
 
-    :raises FileVerificationFailed: if the file failed verification
+    Raises:
+        ValidateError: If the file failed verification
     """
     # Validation is turned off.
     if not is_validate():
         return
 
+    if not os.path.exists(path):
+        raise ValidateError(f'{path} does not exist')
+
     ext = os.path.splitext(path)[1]
     if ext in VALIDATORS:
         VALIDATORS[ext](path)
-        logger.debug('{} passed validation'.format(path))
+        logger.debug(f'{path} passed validation')
 
 
-def validate_files(pre=True, post=True):
+def validate_files(pre: bool = True, post: bool = True) -> Callable:
     """Function decorator to validate input/output files.
 
     This function does not validate when the current run is a dry run.
+    The decorated function is expected to return a dictionary of paths as
+    values.
 
-    :param pre: whether to validate input files, defaults to `True`
-    :type pre: bool
-    :param post: whether to validate output files, defaults to `True`
-    :type post: bool
+    Args:
+        pre: Whether to validate input files, defaults to `True`
+        post: Whether to validate output files, defaults to `True`
 
-    :return: wrapped function
-    :rtype: function
+    Returns:
+        Wrapped function
     """
 
     def wrapper(func):
@@ -109,17 +115,10 @@ def validate_files(pre=True, post=True):
 
             results = func(*args, **kwargs)
 
+            # Assume results are in the form
             if not is_dry() and post:
-                to_check = []
-                if isinstance(results, str):
-                    to_check.append(results)
-                if isinstance(results, (list, tuple)):
-                    to_check += results
-                if isinstance(results, dict):
-                    to_check += list(results.values())
-                for arg in to_check:
-                    if isinstance(arg, str) and os.path.exists(arg):
-                        validate(arg)
+                for path in results.values():
+                    validate(path)
 
             return results
 
